@@ -481,9 +481,6 @@ class VegaServiceNull(VegaService):
         )
         self.retain_log_files = retain_log_files
 
-        import pdb
-
-        pdb.set_trace()
         self.vega_path = vega_path or os.environ.get(
             "VEGA_CORE", path.join(vega_bin_path, "vega")
         )
